[![Version](https://earth.bsc.es/gitlab/es/nes/-/badges/release.svg?key_text=Latest+release&value_width=80)](https://earth.bsc.es/gitlab/es/nes/-/tags)

# About

NES (NetCDF for Earth Science) is the Python I/O library used by SNES, the framework that implements the data post-processing pipelines at the Earth Sciences department, to read and write netCDF files.

## How to install

Use the following command to install the library:

```
pip install nes
```

Read the [FAQ](https://earth.bsc.es/gitlab/es/nes/-/wikis/faq) if you encounter any problems. If they do not resolve your issues, please contact the developers.

## How to run

To run the library, please follow the instruction in the [wiki](https://earth.bsc.es/gitlab/es/nes/-/wikis/home).